==> atlassian-plugins-webresource-2.5.5-sources.jar: com/atlassian/plugin/webresource/transformer/AbstractStringTransformedDownloadableResource.java <==
package com.atlassian.plugin.webresource.transformer;

import com.atlassian.plugin.servlet.DownloadException;
import com.atlassian.plugin.servlet.DownloadableResource;
import org.apache.commons.io.IOUtils;

import java.io.*;

/**
 * Abstract class that makes it easy to create transforms that go from string to string.  Override
 * {@link #getEncoding()} to customize the character encoding of the underlying content and transformed content.
 * <p>
 * For example, here is a minimal transformer that prepends text to the underlying resource:
 * <pre>
 * public class PrefixTransformer implements WebResourceTransformer
 *   {
 *       public DownloadableResource transform(Element configElement, ResourceLocation location, String filePath, DownloadableResource nextResource)
 *       {
 *           return new AbstractStringTransformedDownloadableResource(nextResource)
 *           {
 *               protected String transform(String originalContent)
 *               {
 *                   return "Prefix: "  + originalContent;
 *               }
 *           };
 *       }
 *    }
 * </pre>
 *
 * @since 2.5.0
 */
public abstract class AbstractStringTransformedDownloadableResource extends AbstractTransformedDownloadableResource
{

    public AbstractStringTransformedDownloadableResource(DownloadableResource originalResource)
    {
        super(originalResource);
    }

    public void streamResource(OutputStream out) throws DownloadException
    {
        ByteArrayOutputStream delegateOut = new ByteArrayOutputStream();
        try
        {
            getOriginalResource().streamResource(delegateOut);
        }
        catch (DownloadException e)
        {
            throw e;
        }
        try
        {
            String originalContent = new String(delegateOut.toByteArray(), getEncoding());
            String transformedContent = transform(originalContent);
            IOUtils.copy(new StringReader(transformedContent.toString()), out, getEncoding());
        }
        catch (UnsupportedEncodingException e)
        {
            // should never happen
            throw new DownloadException(e);
        }
        catch (IOException e)
        {
            throw new DownloadException("Unable to stream to the output", e);
        }

    }

    /**
     * @return the encoding used to read the original resource and encode the transformed string
     */
    protected String getEncoding()
    {
        return "UTF-8";
    }

    /**
     * Override this method to transform the original content into a new format.
     *
     * @param originalContent The original content from the original downloadable resource.
     * @return The transformed content you want returned
     */
    protected abstract String transform(String originalContent);
}

==> atlassian-plugins-webresource-2.9.3-sources.jar: com/atlassian/plugin/webresource/transformer/AbstractStringTransformedDownloadableResource.java <==
package com.atlassian.plugin.webresource.transformer;

import static com.atlassian.plugin.webresource.transformer.TransformerUtils.UTF8;
import static com.atlassian.plugin.webresource.transformer.TransformerUtils.transformAndStreamResource;

import com.atlassian.plugin.servlet.DownloadException;
import com.atlassian.plugin.servlet.DownloadableResource;

import com.google.common.base.Function;

import java.io.OutputStream;
import java.nio.charset.Charset;

/**
 * Abstract class that makes it easy to create transforms that go from string to string.  Override
 * {@link #getEncoding()} to customize the character encoding of the underlying content and transformed content.
 * <p>
 * For example, here is a minimal transformer that prepends text to the underlying resource:
 * <pre>
 * public class PrefixTransformer implements WebResourceTransformer
 *   {
 *       public DownloadableResource transform(Element configElement, ResourceLocation location, String filePath, DownloadableResource nextResource)
 *       {
 *           return new AbstractStringTransformedDownloadableResource(nextResource)
 *           {
 *               protected String transform(String originalContent)
 *               {
 *                   return "Prefix: "  + originalContent;
 *               }
 *           };
 *       }
 *    }
 * </pre>
 *
 * @since 2.5.0
 * @deprecated since 2.9.0 use {@link CharSequenceDownloadableResource} instead
 */
@Deprecated
public abstract class AbstractStringTransformedDownloadableResource extends AbstractTransformedDownloadableResource
{
    private final Function<CharSequence, CharSequence> transformer = new Function<CharSequence, CharSequence>()
    {
        public CharSequence apply(final CharSequence originalContent)
        {
            return transform(originalContent.toString());
        }
    };

    public AbstractStringTransformedDownloadableResource(final DownloadableResource originalResource)
    {
        super(originalResource);
    }

    public void streamResource(final OutputStream out) throws DownloadException
    {
        transformAndStreamResource(getOriginalResource(), Charset.forName(getEncoding()), out, transformer);
    }

    /**
     * @return the encoding used to read the original resource and encode the transformed string
     */
    protected String getEncoding()
    {
        return UTF8.name();
    }

    /**
     * Override this method to transform the original content into a new format.
     *
     * @param originalContent The original content from the original downloadable resource.
     * @return The transformed content you want returned
     */
    protected abstract String transform(String originalContent);
}
